# Use Case Tutorials

This section provides a set of concrete examples that showcase how to use AutoRA for different purposes. These examples and use cases are designed to give you a head start on building your own AutoRA workflow for research projects.

Each example walks through a complete workflow, from setting up the experiment to analyzing results, allowing you to see AutoRA in action. Whether you are setting up a basic procedure for automated piloting of experimental data, or a closed-loop study involving iterations between model discovery and experimental design, these examples will guide you through the key steps and provide code snippets to help you along the way.

### How to Use the Examples

- **Follow along:** Each example is self-contained and includes the necessary code and explanations. Simply follow along, and adapt the code to your specific use case.
- **Modify for your needs:** These examples are designed as starting points. You can easily modify parameters, data inputs, or algorithms to fit your research domain.
- **Integrate with existing projects:** Use these examples as a template to integrate AutoRA with your ongoing research projects.

If you are new to AutoRA, we recommend that you first look into its basic components and workflow. For an overview of these features, please refer to the [Basic Tutorials](../tutorials/index.md) section.

Let's dive into the first example to see how you can get started with AutoRA in your experiments. If you are interested in using AutoRA for running closed-loop behavioral research studies, we recommend that you start with the [Closed-Loop Psychophysics Study](closed-loop-basic/index.md).

